@@ -3,17 +3,24 @@ from vasp.parser.regex import parse_vector, atom_header
 
 
 class Poscar:
+    """
+    This poscar parser *only* parses the poscar, it does not apply
+    any transformation or conversion from cartesian into direct or
+    otherwise.
+
+    :param poscar_path: Path to a poscar file
+    :type  poscar_path: str
+    """
 
     def __init__(self, poscar_path):
-        # Wether cartesian or direct
-        self.modeline = None
-        self.basis = []
-        self.name = ""
-        self.constant = None
-        self.symbols = []
-        self.symbols_number = []
-        self.natoms = None
-        self.coordinates = []
+        self.modeline = None #: Wether cartesian or direct
+        self.basis = [] #: Basis elements
+        self.name = "" #: Name of the system
+        self.constant = None #: Multiplicative constant
+        self.symbols = [] #: Atomic labels
+        self.symbols_number = [] #: Atomic numbers
+        self.natoms = None #: Number of atoms
+        self.coordinates = [] #: Coordinates
 
         with open(poscar_path) as fd:
             self.lines = fd.readlines()
